
<h1>Installing graspi_networkx via pip</h1>
<p>Below are instrictions regarding how to install graspi_networkx.</p>

## INSTALLATION
1. ```bash
   pip install graspi-networkx==0.1.5
   ```
2. That's it
<br>
<h2>USING THE PACKAGE</h2>
<p>After installing all dependencies, you're able to follow this formula in the command line</p>
<h3> importing graspi_networkx via notebook/python script</h3>

```bash
import graspi_networkx as gn
```
<h3> Command Line Formula</h3>

```bash
python .\main
```
Example
```bash

```
<h3>OUTPUTS</h3>

* Nodes and edges for the created graph
* Nodes and edges for the created subgraph
* Node 0 represents a blue cathode and Node 1 represents a red anode
